import 'package:flutter/material.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/page_wrapper.dart';

class TextFieldExample extends StatefulWidget {
  const TextFieldExample({Key? key}) : super(key: key);

  @override
  State<TextFieldExample> createState() => _TextFieldExampleState();
}

class _TextFieldExampleState extends State<TextFieldExample> {
  final TextEditingController nameFieldController = TextEditingController();
  final int maxLength = 20;
  bool enabled = true;

  @override
  Widget build(BuildContext context) {
    final GlobalKey<FormState> _formKey = GlobalKey<FormState>();

    return PageWrapper(
      title: 'Text Field',
      child: Form(
        key: _formKey,
        child: SingleChildScrollView(
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              SeniorSwitch(
                onChanged: (value) {
                  if (value != null) {
                    setState(() {
                      enabled = value;
                    });
                  }
                },
                value: enabled,
                title: 'Habilitar campos',
                titlePosition: SeniorSwitchTitlePosition.right,
              ),
              SeniorTextField(
                label: 'Nome',
                controller: nameFieldController,
                maxLength: maxLength,
                hintText: 'Informe o seu nome',
                counterText: 'caracteres restantes',
                helper: 'Favor digitar o nome',
                showCounterText: true,
                disabled: !enabled,
                style: const SeniorTextFieldStyle(
                  hintTextColor: Colors.blue,
                  helperTextColor: Colors.amber,
                  counterColor: Colors.green,
                ),
              ),
              SeniorTextFieldPassword(
                label: 'Senha',
                disabled: !enabled,
              ),
              SeniorTextField(
                label: 'Código',
                helper: 'Código',
                hintText: 'Código',
                disabled: !enabled,
                validator: (value) {
                  if (value == null || value.isEmpty) {
                    return 'Código precisa ser informado';
                  }
                  return null;
                },
              ),
              SeniorButton.primary(
                  label: 'Validar',
                  onPressed: () {
                    _formKey.currentState?.validate();
                  })
            ],
          ),
        ),
      ),
    );
  }
}
